# Test Files Directory

This directory is to contain files to be used to run unit tests.

Some of these unit tests will depend on static files such as previously cloned git 
repositories as dependencies. 

In the case of git repositories, these files are to be held in `tar.gz` files and are
 to only be unzipped during the testing setup method. Do NOT commit git repos directly
to the repository!!
